Modified:
trunk/src/edu/hawaii/duedates/webApp/AlertsPage.java
trunk/src/edu/hawaii/duedates/webApp/TestResultPage.java
Log:
fixed minor things in TestResultPage.java. Also took out small tester code
in AlertsPage.java.
Modified: trunk/src/edu/hawaii/duedates/webApp/AlertsPage.java
==============================================================================
--- trunk/src/edu/hawaii/duedates/webApp/TestResultPage.java (original)
+++ trunk/src/edu/hawaii/duedates/webApp/TestResultPage.java Mon Dec 8
12:23:02 2008
@@ -52,7 +52,7 @@
final String RESULT_FORM = "resultForm";
- // Start up the WicketTester and check that the startpage renders.
+ // Start up the WicketTester and check that the start page renders.
WicketTester tester = new WicketTester(new
DueDatesApplication(config));
tester.startPage(Index.class);
@@ -91,9 +91,6 @@
// Test that data output shows up
assertTrue("items exist",
tester.getTagByWicketId(RESULT_FORM).getMarkup().
contains("itemTable"));
-
- tester.dumpPage();
- tester.debugComponentTrees();
assertNotNull("Testing wicket:id library found.",
tester.getTagByWicketId("library"));
assertNotNull("Testing wicket:id titile found",
tester.getTagByWicketId("title"));
--- trunk/src/edu/hawaii/duedates/webApp/AlertsPage.java (original)
+++ trunk/src/edu/hawaii/duedates/webApp/AlertsPage.java Mon Dec 8
12:23:02 2008
@@ -55,10 +55,10 @@
/** Support serialization. */
private static final long serialVersionUID = 1L;
/** Only visible if user has UH library credentials */
@Override
public boolean isVisible() {
- return getDueDatesSession().hasUh();
+ return getDueDatesSession().hasHsl();
}
});
@@ -93,8 +93,7 @@
//for outputs after the first
DueDateTimer dueDateTimer = new DueDateTimer(alerts);
timer.scheduleAtFixedRate(dueDateTimer, date.getTime(),
- Long.valueOf(Math.round(1000 * 3600 * 24 *
alerts.getWakeupValue())//));
- / 24 / 60)); // temporary to get it to email once per
minute for testing.
+ Long.valueOf(Math.round(1000 * 3600 * 24 *
alerts.getWakeupValue())));
getDueDatesSession().setAlertResponse("Alerts started
Successfully");
@@ -55,10 +55,10 @@
/** Support serialization. */
private static final long serialVersionUID = 1L;
- /** Only visible if user has UH library credentials */
+ /** Only visible if user has Hsl library credentials */
public boolean isVisible() {
setResponsePage(AlertsPage.class);
Modified: trunk/src/edu/hawaii/duedates/webApp/TestResultPage.java
==============================================================================